@@ -3,6 +3,7 @@ import math
 from collections.abc import Iterable
 from copy import deepcopy
 
+import cloudpickle
 import numpy as np
 import sortedcollections
 import sortedcontainers
@@ -51,6 +52,13 @@ def default_loss(xs, ys):
         return np.hypot(dx, dy)
 
 
+@uses_nth_neighbors(0)
+def abs_min_log_loss(xs, ys):
+    """Calculate loss of a single interval that prioritizes the absolute minimum."""
+    ys = [np.log(np.abs(y).min()) for y in ys]
+    return default_loss(xs, ys)
+
+
 @uses_nth_neighbors(1)
 def triangle_loss(xs, ys):
     xs = [x for x in xs if x is not None]
@@ -69,6 +77,43 @@ def triangle_loss(xs, ys):
     return sum(vol(pts[i : i + 3]) for i in range(N)) / N
 
 
+def resolution_loss_function(min_length=0, max_length=1):
+    """Loss function that is similar to the `default_loss` function, but you
+    can set the maximum and minimum size of an interval.
+
+    Works with `~adaptive.Learner1D` only.
+
+    The arguments `min_length` and `max_length` should be in between 0 and 1
+    because the total size is normalized to 1.
+
+    Returns
+    -------
+    loss_function : callable
+
+    Examples
+    --------
+    >>> def f(x):
+    ...     return x**2
+    >>>
+    >>> loss = resolution_loss_function(min_length=0.01, max_length=1)
+    >>> learner = adaptive.Learner1D(f, bounds=[(-1, -1), (1, 1)], loss_per_triangle=loss)
+    """
+
+    @uses_nth_neighbors(0)
+    def resolution_loss(xs, ys):
+        loss = uniform_loss(xs, ys)
+        if loss < min_length:
+            # Return zero such that this interval won't be chosen again
+            return 0
+        if loss > max_length:
+            # Return infinite such that this interval will be picked
+            return np.inf
+        loss = default_loss(xs, ys)
+        return loss
+
+    return resolution_loss
+
+
 def curvature_loss_function(area_factor=1, euclid_factor=0.02, horizontal_factor=0.02):
     # XXX: add a doc-string
     @uses_nth_neighbors(1)
@@ -627,7 +672,7 @@ class Learner1D(BaseLearner):
 
     def __getstate__(self):
         return (
-            self.function,
+            cloudpickle.dumps(self.function),
             self.bounds,
             self.loss_per_interval,
             dict(self.losses),  # SortedDict cannot be pickled
@@ -637,6 +682,7 @@ class Learner1D(BaseLearner):
 
     def __setstate__(self, state):
         function, bounds, loss_per_interval, losses, losses_combined, data = state
+        function = cloudpickle.loads(function)
         self.__init__(function, bounds, loss_per_interval)
         self._set_data(data)
         self.losses.update(losses)
